#ifndef NT2_INCLUDE_CONSTANTS_FACT_11_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FACT_11_HPP_INCLUDED

#include <nt2/constant/include/constants/fact_11.hpp>

#endif
